@@ -65,6 +65,7 @@ use App::Dochazka::REST::Model::Shared qw(
     priv_by_eid 
     schedule_by_eid 
     select_set_of_single_scalar_rows
+    timestamp_delta_plus
 );
 use App::Dochazka::REST::ResourceDefs;
 use App::Dochazka::REST::Shared qw( :ALL );  # all the shared_* functions
@@ -1686,6 +1687,8 @@ sub _handler_get_intlock {
 
     # first pass
     if ( $pass == 1 ) {
+
+        # determine the employee
         my $value;
         if ( $key eq 'self' ) {
             $key = 'eid';
@@ -1703,11 +1706,25 @@ sub _handler_get_intlock {
         }
         my $emp = shared_first_pass_lookup( $self, $key, $value );
         return 0 unless $emp;
-        my $status;
+
+        # determine the tsrange
+        my $mapping = $context->{'mapping'};
+        my ( $status, $tsr );
+        $tsr = $mapping->{'tsrange'} if $mapping->{'tsrange'};
+        if ( $mapping->{'ts'} and $mapping->{'psqlint'} ) {
+            $status = timestamp_delta_plus( 
+                $context->{'dbix_conn'}, 
+                $mapping->{'ts'}, 
+                $mapping->{'psqlint'} 
+            ); 
+            return $status unless $status->ok;
+            $tsr = "[ " . $mapping->{ts} . ", " . $status->payload . " )";
+        }
+            
         my @ARGS = (
             $context->{'dbix_conn'},
             $emp->eid,
-            $context->{'mapping'}->{'tsrange'} 
+            $tsr,
         );
         if ( $intlock eq 'Interval' ) {
             $status = App::Dochazka::REST::Model::Interval::fetch_by_eid_and_tsrange( @ARGS );
